package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````?1<``#0```#(@0````0`!30`(``)
M`"@`&P`:``$``'!L>@``;'H``&QZ```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!X>@``>'H```4```````$`
M`0```)A]``"8?0$`F'T!`*@"``#`$@``!@```````0`"````H'T``*!]`0"@
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DF'T`
M`)A]`0"8?0$`:`(``&@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50!/VT%$4IYW`<T)$,W:8-P]+0U2RQ$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%````!1````50``
M`%H```!;````8@```&,```!D````9@```&<`````````:0```&H```!K````
M;0```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````"<$@````````,`"P```````(`!```````#`!8`
MH@(`````````````$@```%`#`````````````!(````D`P`````````````B
M````:0,`````````````$0````8$`````````````!(````1````````````
M```@````%0(`````````````$@```/8"`````````````!(```!!`P``````
M```````2````$0$`````````````$@```(<#`````````````!$```"T````
M```````````2````O0(`````````````$@```(,!`````````````!(```"I
M`@`````````````2````A```````````````$@````P!`````````````!(`
M``#$`@`````````````2````A@(`````````````$@```$P"````````````
M`!(````D`@`````````````2````70(`````````````$@```&H"````````
M`````!(````!`0`````````````1````9P$`````````````$@```.,`````
M`````````!$````U`0`````````````2````_0(`````````````$@```.\"
M`````````````!$````&`P`````````````2````P@``````````````$@``
M`+$!`````````````!(````-`@`````````````2````G@$`````````````
M$@```-T"`````````````!(```#U`0`````````````2````J@$`````````
M````$@```%<#`````````````!(```!#`0`````````````2````+0``````
M````````(````'\"`````````````!(````V`@`````````````2````E`(`
M````````````$@```+P!`````````````!$```!D```````````````2````
M$P,`````````````$@```),``````````````!(```#\`0`````````````2
M````,P,`````````````$@```)\``````````````!(```!<`0``````````
M```2````9`(`````````````$@```)L"`````````````!(````B`0``````
M```````2````5@``````````````$@```!8!`````````````!(```"3`0``
M```````````2````KP(`````````````$@```/```````````````!(```!X
M`@`````````````2````20,`````````````$@```(T"`````````````!(`
M``!U`0`````````````2````<P``````````````$@```&H#````````````
M`"$````:`P`````````````2````U```````````````$@```%,!````````
M`````!(````\```````````````@````:P,`````````````$0```.4"````
M`````````!(````[`@`````````````2````<@(`````````````$@```.\!
M`````````````!(```#2`@`````````````2````0P(`````````````$@``
M`-L!`````````````!(```"[`P``6)`!```````0`!<`#P0``!$Z``!0````
M$@`-`-T#``#`.@```````!(`#@`T!```L2\``*@'```2``T`9`,``,D5``"T
M`0``$@`-`.,#``"1*@``!````!(`#0"L`P``0(`!```````0`!<`H@0``)4J
M``"T`0``$@`-`)P$``"<$@```````!(`"P#/!```63<``+@"```2``T`H`,`
M`$"``0``````$``7`!L$``!)+```%@```!(`#0!.!```R#H```0````1``\`
MS@,``%B0`0``````$``7`,8#``!8D`$``````!``%P":!```>2D``#@````2
M``T`KP0``!4O``"<````$@`-`,$$``"E+@``8````!(`#0!!!````(`!````
M```0`!8`*`0``&$L``#`````$@`-`)D#``!`@`$``````!``%@"#!```/(`!
M``0````1`!8`TP,``+TZ```"````$@`-`',$``"!.@``/````!(`#0!'!```
M?1<````````2``T`0P0```"``0``````(``6`/0#```%+P``$````!(`#0"Z
M`P``6)`!```````0`!<`700``/TI``"4````$@`-`(T$```A+0``A`$``!(`
M#0``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I
M8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`
M;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!C;&]S
M961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B
M;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X
M85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M
M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M87)M:&8N
M<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B
M<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R
M7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#
M7S(N-````````````@`"``(``@`"`````P`"``(``@`$`````@````(`````
M``(``@`"``(``@`"`````````````@`"``(```````,````"``,``@`"````
M```"``(``@```````@````,``@```````@`"`````````````@````(``@`"
M```````"``(``````````@`"``(``@`#``(``@`#``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0!S`P``$````"`````4:6D-```$`.4$`````````0`!`,L!```0````
M(````!1I:0T```,`Y00````````!``$`&@(``!``````````%&EI#0```@#E
M!````````)A]`0`7````G'T!`!<```"\?P$`%P```.!_`0`7````Z'\!`!<`
M``#P?P$`%P````2``0`7````#(`!`!<````0@`$`%P```!B``0`7````'(`!
M`!<````@@`$`%P```"2``0`7````*(`!`!<````P@`$`%P```#2``0`7````
M/(`!`!<```#`?P$`%04``,1_`0`5"```R'\!`!4-``#,?P$`%1```-!_`0`5
M&@``U'\!`!4<``#8?P$`%1\``-Q_`0`5*@``Y'\!`!4N``#L?P$`%3@``/1_
M`0`50@``^'\!`!5'``#\?P$`%4@``+Q^`0`6`P``P'X!`!8$``#$?@$`%@4`
M`,A^`0`6!P``S'X!`!8)``#0?@$`%@H``-1^`0`6"P``V'X!`!8,``#<?@$`
M%@X``.!^`0`6#P``Y'X!`!81``#H?@$`%A(``.Q^`0`6$P``\'X!`!84``#T
M?@$`%A4``/A^`0`6%@``_'X!`!87````?P$`%A@```1_`0`6&0``"'\!`!8;
M```,?P$`%AT``!!_`0`6'@``%'\!`!8@```8?P$`%B$``!Q_`0`6(@``('\!
M`!8C```D?P$`%B0``"A_`0`6)0``+'\!`!8F```P?P$`%B<``#1_`0`6*```
M.'\!`!8I```\?P$`%BH``$!_`0`6*P``1'\!`!8L``!(?P$`%BT``$Q_`0`6
M+P``4'\!`!8P``!4?P$`%C$``%A_`0`6,@``7'\!`!8S``!@?P$`%C0``&1_
M`0`6-0``:'\!`!8V``!L?P$`%C<``'!_`0`6.0``='\!`!8Z``!X?P$`%CL`
M`'Q_`0`6/```@'\!`!8]``"$?P$`%CX``(A_`0`6/P``C'\!`!9```"0?P$`
M%D$``)1_`0`61```F'\!`!9%``"<?P$`%D8``*!_`0`620``I'\!`!9*``"H
M?P$`%DL``*Q_`0`63```L'\!`!9-``"T?P$`%DX``+A_`0`63P``"$`MZ4<!
M`.L(@+WH!.`MY03@G^4.X(_@"/"^Y?AK`0``QH_B%LJ,XOC[O.4`QH_B%LJ,
MXO#[O.4`QH_B%LJ,XNC[O.4`QH_B%LJ,XN#[O.4`QH_B%LJ,XMC[O.4`QH_B
M%LJ,XM#[O.4`QH_B%LJ,XLC[O.4`QH_B%LJ,XL#[O.4`QH_B%LJ,XKC[O.4`
MQH_B%LJ,XK#[O.4`QH_B%LJ,XJC[O.4`QH_B%LJ,XJ#[O.4`QH_B%LJ,XIC[
MO.4`QH_B%LJ,XI#[O.5X1\!&`,:/XA;*C.*$^[SE`,:/XA;*C.)\^[SE>$?`
M1@#&C^(6RHSB</N\Y0#&C^(6RHSB:/N\Y0#&C^(6RHSB8/N\Y0#&C^(6RHSB
M6/N\Y0#&C^(6RHSB4/N\Y0#&C^(6RHSB2/N\Y0#&C^(6RHSB0/N\Y0#&C^(6
MRHSB./N\Y0#&C^(6RHSB,/N\Y0#&C^(6RHSB*/N\Y0#&C^(6RHSB(/N\Y0#&
MC^(6RHSB&/N\Y0#&C^(6RHSB$/N\Y0#&C^(6RHSB"/N\Y0#&C^(6RHSB`/N\
MY0#&C^(6RHSB^/J\Y0#&C^(6RHSB\/J\Y0#&C^(6RHSBZ/J\Y0#&C^(6RHSB
MX/J\Y0#&C^(6RHSBV/J\Y0#&C^(6RHSBT/J\Y0#&C^(6RHSBR/J\Y0#&C^(6
MRHSBP/J\Y0#&C^(6RHSBN/J\Y0#&C^(6RHSBL/J\Y0#&C^(6RHSBJ/J\Y7A'
MP$8`QH_B%LJ,XISZO.4`QH_B%LJ,XI3ZO.4`QH_B%LJ,XHSZO.4`QH_B%LJ,
MXH3ZO.4`QH_B%LJ,XGSZO.4`QH_B%LJ,XG3ZO.4`QH_B%LJ,XFSZO.4`QH_B
M%LJ,XF3ZO.4`QH_B%LJ,XESZO.4`QH_B%LJ,XE3ZO.4`QH_B%LJ,XDSZO.4`
MQH_B%LJ,XD3ZO.4`QH_B%LJ,XCSZO.4`QH_B%LJ,XC3ZO.4`QH_B%LJ,XBSZ
MO.4`QH_B%LJ,XB3ZO.4`QH_B%LJ,XASZO.4`QH_B%LJ,XA3ZO.4`QH_B%LJ,
MX@SZO.4`QH_B%LJ,X@3ZO.4`QH_B%LJ,XOSYO.4`QH_B%LJ,XO3YO.7PM8FP
M6$Q92WQ$!9`$D06H`Y($J>98`ZHS:`>3__=&[U-*5$NB6.!8$48"\#7Z4DOC
M6!]X`"]IT%!+Y5@H:/_WVN^0^`XT`D8H:$/P`@."^`XT__?0[P6;!3.S\8!/
MD/@.)$+P`0*`^`XD:=*8``0G__?@[D)*!)UZ1$)+$6A[1$%*+&AZ1$-@P.D"
M$C]+!9I[1`1@`2K#Z0%P"MWK&0#Q#`$%ZX(%4_@$2ZM"0?@$3_G1-T\"\8!!
M`"0#,7]$`)1`^"%``T8]:0,R,DDH1GE$__<P[P1&<+,O30:O?40H:?_W?NXM
M2#E&>$0`\"W_Z+$K2WM$&&G_]T;N__<0[P>:,V@@1II"*M$)L/"]__>&[B1*
M>D0082"S__<N[A=+Y5@H:/_W:.^`^(%VA^?H:&BQ`O"*^=SG.&G_]S+O!$;+
MYQE+&DCA6'A$__?.[AA(.49X1`#P^?[H8``HR=#HY__W)NX!(/_WEN[<:`$`
M&`$``#P!``!$`0``)`$``"`!``#X:0$`OB<``+PG``#H:0$`O&D!`!<3``"<
M:0$`$"4``(9I`0!F:0$`-`$``"XF``!$)```3_``"T_P``X"O&I&!+0!M-_X
M)*`(HYI$W_@@P%KX#,!-^`3-!DM:^`,P!DA:^```__<^[O_W[.[\9@$`#`$`
M`#@!``!``0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!&/__ZMQF`0`L`0``
M!D@'2WA$!TI[1(-">D0#T`5+TU@#L1A'<$<`OU!H`0!,:`$`N&8!`!0!```(
M2`E+>$0)2GM$&1IZ1(D0`>O1<4D0`]`%2]-8`[$81W!'`+\D:`$`(&@!`(QF
M`0!(`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(2WM$&&C_]SCM__>__P9+`2)[
M1!IP"+WN9P$`7&8!`!`!``"B9P$`SF<!`,3G`+\`````W_AT/-_X="Q[1"WI
M\$^M]25]FU@-\0@,`/%`!0#Q@`=D1@`F`9,;:*.35>D"$@@UKT)F8.9@";I/
MZA(C3^H"+@/T?T,.]'\.0^H28R%@0^H"8P3Q$`1#Z@X#1/@(/.31#/7\?&]&
M`"6&1CY&5_@(#S)OLVQG1;1I<6^#Z@(#\FR#Z@0#]&F#Z@`#@NH!`GEH@NH$
M`D_JTW2"Z@$"Q_B$4$3J0@1$ZD,#Q_B`,-W1<$;>Z0)CWND`Q`=I3^J6#H)I
M3NJ#?@*93^K<98?J`@E']ID3`FK%]H(C1>I$%<D81>I,%8D8:1B%:02:">H&
M"4[JAGZ)Z@4)3^J<!1'K"0&'Z@X(1>J$==08@FD(Z@P(1>J,=8CJ!PBD&`::
MCNH%"13K"`1/ZO%H%.L(!`GJ`0D2ZP,(3^JQ`8GJ#@(8ZP<(W?@@D$_J]&H8
MZP("A>H!"!+K"@((Z@0(&>L#"4_JM`2(Z@4(&>L.#MWX*)!/ZO)J'NL(#H'J
M!`@>ZPH.".H""!GK`PE/ZK("B.H!"!GK!07=^#"03^K^:A7K"`6$Z@((%>L*
M!0CJ#@@9ZP,)3^J^#HCJ!`@9ZP$!W?@XH!'K"`&"Z@X)3^KU:!'K"`@)Z@4)
M&NL#"D_JM0&)Z@()&NL$!-WX0*".Z@$%%.L)!$_J^&D4ZPD$!>H(!1KK`PI/
MZK@(A>H.!1KK`@+=^$B@4AF!Z@@)3^KT9549">H$"1KK`PH*1AKK#@Y/ZK0!
MW?A0H(GJ`@0>ZP0$3^KU:8CJ`0X4ZPD$#NH%#AKK`PE/ZK4%&>L""8[J"`Y"
M1MWX6(!/ZO1J&>L.#H'J!0D>ZPH.">H$"1CK`PC=^&"@&.L""$_JM`*)Z@$$
M3^K^:1CK!`2%Z@((%.L)!`CJ#@@:ZP,)3^J^#AGK`0F(Z@4(*48:G4_J]&H9
MZP@(@NH."1CK"@@)Z@0)[1AM&-WX<*!/ZK0!B>H"!"P93^KX:8[J`044ZPD$
M!>H(!1KK`PE/ZK@(&>L""7)&W?AXX%5`3^KT:AGK!06!Z@@)%>L*!0GJ!`D>
MZP,.W?B`H![K`@Y/ZK0"B>H!!$_J]6D>ZP0$B.H"#A3K"00.Z@4.&NL#"4_J
MM06.Z@@.&>L!"4%&W?B(@$_J]&H9ZPX)@NH%#AGK"@D.Z@0.&.L#"$_JM`2.
MZ@(.&.L!`=WXD(!/ZOEJ$>L.`87J!`X1ZPH!#NH)#ACK`PA/ZKD)CNH%#ACK
M`@+=^)B`3^KQ:A+K#@*$Z@D.$NL*`@[J`0X8ZP,(3^JQ`1CK!06.Z@0(W?B@
MX$_J\FH5ZP@(B>H!!1CK"@@50![K`PZ%Z@D%'NL$#BJ;3^JR`A[K!0Y.]J$T
M3^KX9<;VV60>ZP4.@>H"!1L9A>H(!1/K"0DLFT_JN`@9ZP4)3^K^91GK!0F"
MZ@@%&QF%Z@X%6Q@NF4_JO@Y;&4_J^65;&8CJ#@4)&87J"06)&#":3^JY"4T9
M3^KS86T8CNH)`1(964`2ZP@(,II/ZK,#&.L!`4_J]6B)Z@,*$>L(`1(9BNH%
M"MWXT(`2ZPX"3^JU!4_J\6X2ZPH"$NL.`H/J!0H8ZP0.BNH!"A[K"0[=^-B`
M3^JQ`4_J\FD>ZPH.W?CPH![K"0Z%Z@$)&.L$"(GJ`@D8ZP,#W?C@@!/K"0E/
MZK(#3^K^8AGK`@*!Z@,)&.L$"(GJ#@D8ZP4(.IU/ZKX.&.L)"$_J\FD8ZPD(
M@^H."2T9B>H""6D83^JR!1'K"0%/ZOABB1B.Z@4)&NL$`HGJ"`G=^/B@TA@2
MZPD"3^JX`T_J\6B%Z@,)$NL(`AKK!`B)Z@$)W?@`H1CK#@A/ZK$!3^KR;ACK
M"0@8ZPX(@^H!"1KK!`Z)Z@()'NL%#D*=3^JR`A[K"0Y/ZOAIW?@0H1[K"0Z!
MZ@()+1F)Z@@)ZQA/ZK@%$^L)`T_J_F@3ZP@#@NH%"1KK!`B)Z@X)&.L!`=WX
M&*$1ZPD)3^J^`4_J\VZ%Z@$(&>L."1KK!`X>ZP("B.H#"-WX(.$2ZP@(3^JS
M`D_J^6,8ZP,(@>H""A[K!`.*Z@D*71G=^"CA3^JY`Q7K"@5/ZOAI%>L)!8+J
M`PD>ZP0.B>H("1[K`0'=^##A3^JX"!'K"0%/ZO5I$>L)`8/J"`D>ZP0.B>H%
M"1[K`@Y.FD_JM04>ZPD.3^KQ:1[K"0Z(Z@4)$AF)Z@$)TAA0FT_JL0$2ZPD"
M3^K^:1+K"0*%Z@$)&QF)Z@X)$^L(!-WX2(%/ZKX.3^KR:A3K"01+]MQ#R/8;
M<Q3K"@1!Z@X)&.L#"*I&">H""4_JL@48ZPH"`>H."MWX4(%)Z@H)3NH%"A+K
M"0)/ZO1I$NL)`@KJ!`H.Z@4)&.L#"$_JM`1*Z@D*&.L!`=WX6)%%Z@0(&NL!
M`4_J\FH(Z@(($>L*`07J!`H9ZP,)2.H*"!GK#@Y/ZK("&.L.#MWX8(%$Z@(*
M3^KQ:1[K"0X*Z@$*!.H""1CK`PA/ZK$!2NH)"ACK!07=^&B10NH!"!KK!05/
MZOYJ".H."!7K"@4"Z@$*&>L#"4CJ"@@9ZP0$3^J^#ACK!`3=^'"!0>H."D_J
M]6D4ZPD$"NH%"@'J#@D8ZP,(3^JU!4KJ"0H8ZP("W?AXD4[J!0@:ZP("3^KT
M:@CJ!`@2ZPH"#NH%"AGK`PE(Z@H(&>L!`4_JM`08ZP$!W?B`@47J!`I/ZO)I
M$>L)`0KJ`@H%Z@0)&.L#"$_JL@)*Z@D*&.L.#MWXB)%$Z@((&NL.#D_J\6H(
MZ@$('NL*#AGK`PD$Z@(*3^JQ`4CJ"@H9ZP4%W?B0D4+J`0@:ZP4%3^K^:A7K
M"@4(Z@X(`NH!"AGK`PE/ZKX.2.H*"!GK!`IFG$'J#@E/ZO5K&.L*"`GJ!0D8
MZPL(`>H."N083^JU!4GJ"@JD&&B:3NH%"1KK!`1/ZOAJ%.L*!`[J!0L2ZP,*
M">H("4_JN`))Z@L)&NL!"&J91>H""AGK"`E/ZO1H"NH$"AGK"`G)&`7J`@A/
MZK0$2NH("!'K#@YLF4+J!`H8ZPX.3^KY:![K"`X"Z@0+R1@*Z@D*3^JY"$T9
M2NH+"6Z91.H("AGK!05/ZOYI"NH."A7K"04$Z@@)R1A/ZKX.B1A*Z@D*<)I(
MZ@X+&NL!"4_J]6H9ZPH)"^H%`=(8".H."T_JM05!Z@L+$AERF4[J!0I/ZOED
M&^L"`@KJ"0H2&0[J!0O)&$_JN001ZP@(2NH+"7291>H$"AGK"`A/ZO)I&.L)
M"`7J!`L1ZP,)"NH""D_JL@%*Z@L*&>L.#G::1.H!"1KK#@Y/ZOAJ">H("1[K
M"@X$Z@$*TAA/ZK@(2>H*"5(9>)U!Z@@*&>L"`D_J_FD2ZPD""NH."NT8`>H(
M`TKJ`PHM&7J;3^J^#AKK!05,\M843^KR:LSV8B05ZPH%B.H."1L9B>H""5D8
M?)M/ZK("3^KU:A'K"0&.Z@()$>L*`1L9B>H%"1/K"`A^FT_JM048ZPD(3^KQ
M:1CK"0B"Z@4)&QF)Z@$)$^L.#H";'NL)"4_JL0%/ZOANA>H!"AGK#@X;&9H8
MBNH("H*;3^JX"!+K"@I/ZOYB&NL"`H'J"`D;&8GJ#@E=&82;%>L)"4_JO@Y/
MZO)E&>L%!8CJ#@D;&8GJ`@E9&(:;$>L)"4_JL@)/ZO5A&>L!`8[J`@D;&8GJ
M!0D3ZP@(B)L8ZPD)3^JU!4_J\6@9ZP@(@NH%"1L9B>H!"1/K#@Z*FQ[K"0E/
MZK$!3^KX;AGK#@Z%Z@$)&QF)Z@@)FAB,FQ+K"0E/ZK@(3^K^8AGK`@*!Z@@)
M&QF)Z@X)71F.FQ7K"0E/ZKX.3^KR91GK!06(Z@X)&QF)Z@()61B0FQ'K"0E/
MZK("3^KU81GK`0&.Z@()&QF)Z@4)$^L(")*;&.L)"4_JM05/ZO%H&>L("(+J
M!0D;&8GJ`0D3ZPX.E)L>ZPD)3^JQ`4_J^&X9ZPX.A>H!"1L9B>H("9H8EIL2
MZPD)3^JX"$_J_F(9ZP("@>H("1L9B>H."5T9F)L5ZPD)3^J^#D_J\F49ZP4%
MB.H."1L9B>H""5D8FIL1ZPD)3^JR`D_J]6$9ZP$!CNH""1L9B>H%"1/K"`B<
MFQCK"0E/ZK4%3^KQ:!GK"`@;&8+J!0D3ZPX.B>H!"9Z;'NL)"4_JL0%/ZOAN
M&>L.#AL9A>H!"9H8B>H(":";$NL)`D_JN`A/ZOYI&QE*1('J"`2$Z@X$6QD;
M&4_J\F0C1$_JO@X3ZPP#LA@#8``D@VD>ZP<'@F`":ACK`P,'88D8@V%$8`%B
M`9NCFL1@&VA$89I"Q&%$8@/1#?4E?;WH\(_^]S;O%&8!`!@!```MZ?A#($M[
M1``H.-`?2IM8T_@`D+GQ``\ST`-XL_$]!1B_`24`*PB_`"6MN=GX`$!\L0=&
MB$9.1BI&.48@1O_W&.@0N6-=/2L/T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8
MOSTK^=$M&N#G`36FZPD&+$2V$,CX`&`@1KWH^(,$1N?G3$;EYP"_EED!`$P!
M``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_]ZK_L+$12P"8^U@9:`'K@`-:
M:$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_WE/\`*.C1`9HS:)I"`=$#L/"]
M_O>\[@!9`0`8`0``3`$``"WI\$\,1M_X7)&%L%9+!4;Y1`IX6?@#8#TJ"+\!
M-#-H($8#D_[W'.\"J0=&*$;_]VO_@$8`*%30_O<2[[A"1])*2P*:6?@#D$_J
M@@@K>+/Q/0`8OP$@`"L(OP`@.+$H1A#X`3\`*QB_/2OYT4`;`C?9^`"@.$3^
M]]#N2O@(```H:]#9^``@:1P"F"MX4O@@`#TK&+\`*P-P"=!"'!'X`3L01@`K
M&+\]*P+X`3OVT0)&/2,#<!3X`3L"^`$_`"OYT0`@`YHS:)I"2M$%L+WH\(\(
M\?\P%/@!.P#X`3\`*_G1[N<B2UGX`Y#9^`"PV_@`,(.S6T8`X%!&4_@$+P#Q
M`0H`*OC1`S"``!E*>D03:+.Y`2,38/[W@.X!D/"Q3^J*"%E&0D;^]^KM`9O)
M^``P"O$!`@`A0_@B$,WX"*"&YP%&6$;^]RCN`T;)^```*+%/ZHH([.>:1@@@
MUN=/\/\PL.?^]P3NE%@!`!@!``!,`0``+ED!`#-+-$I[1"WI\$^?L)Q8(V@=
MDQ"Q`W@&1C.Y'9HC:)I"5-$?L+WH\(_^]S#N!T8`*//0W_BD@-_XI)#?^*2@
M^$3Y1/I$.$;^]\;NJ+,`\1,%048H1O[W>NT`*//0248H1O[W=.T`*.W0,$;^
M]T#N@T8H1O[W/.Y81`(P_O<4[E-&3_#_,@$A`94`EH-&_O=,[EE&`JH#(/[W
ML.X!,%A&!=`&FP/T<$.S]8!/#-#^][+M6$;^]W#MQ><X1O[WO.XP1O[W>NVI
MY__WF__QY_[WE.TL5P$`&`$``#X3``!`$P``0A,``#BU!4852Q9*>T2<6"!H
M_O>F[BE&`/6D<@,@_O>4[@BQ`"`XO2!H_O>:[M#X6#$#]'!#L_6`3PG0(&C^
M]Y#NT/A8,0/T<$.S]2!/Z=$H1@(A_O<\[K#Z@/!`"3B]1%8!`"`!```MZ?!#
MK?6`729,@[`F2PWU@%9\1`&M@$8D2.=8!#:)1D#V_W(I1GA$.V@S8/[W9NT?
M2P`H*=U&'N-8JET<:-*Q!D8R1B\A*$;^]PCNJ+$@1O[W4NXS1BI&04;^]Q[N
M#?6`4P0S&F@[:)I"&-$-]8!=`["]Z/"#`"[CT2!&_O<\[DI&04;^]S3MZ>?C
M6!QH($;^]S+N2D9!1O[W*NW?Y_[W".T`O]95`0`8`0``'A(``"`!```0M0A,
M"$M\1.-8&&C^]QKN!DH'2P=)HEA[1'E$O>@00/[WD+TN50$`(`$``!P!```X
M$0``AA$```U+#DI[1!"U@K"<6"!H_O?^[?_WV?\@:/[W^.T(2P`A"$I[1,WI
M`#$'27I$>43^]YKM`K`0O0"_^%0!`"`!```N%```>PT``%@1```@2B%+>D3P
MM:WU`%W56(>P#?4`4AU,%#(-]8!6*VA\1!`V$V#^]Q;M&4M!\@$"`2%[1,WI
M``0#K"!&_O<V[2!&,49/](!2_O>^[`0>%MM@'/[WZ.P'1BBQ,48B1O[W9NP`
M(SM5#?4`4SA&%#,::"MHFD(%T0WU`%T'L/"]`"?QY_[W>NRL5`$`&`$``#X1
M```@$0``__>TORWI\$^M]8%=W_AT@8.P74L$1OA$#?6!4EM(!#)8^`,P#?$H
M"0U&>$2I\0@!!9,;:!-@__<C_2\A!D8@1O[WUNR8L5)((49X1/_WE/T@1@WU
M@5,$,QIH!9L;:)I"0/"-@`WU@5T#L+WH\(\@1O[WLNQ'27E$@D8H1O[W%.T'
M1@`HW]!$2]_X$+%[1`:30TO[1'M$!Y,[>``K2]`NL3E&,$;^]\CK`"A*T#A&
M_O>4[$(>NQBZ7"\J!M$`(1EP`3@3^`$M+RKYT`KQ`0,81+#U@%^WVJGQ!`4R
M2@$A6T9Z1`"7`9(H1D_T@%("E/[WDNPM2UCX`W`X:/[W&.TI1@#UI'(#(/[W
M[NQ(N3AH_O<.[=#X6#$#]'!#L_4`3QS0(DD`('E$_O?`[`=&`"^*T#MX`"NS
MT6ZQ!IDP1O[W?.O0N1M)`"!Y1/[WKNP'1@`O[M%XYP>?`2"WYP$A*$;^]Y[L
M`"C<T1-(*49X1/_W!/TH1O[WLNMLYP:?`2"EY_[WLNL`OP94`0`8`0``HA``
M`(X0``!R$```W`\``%H0``#4#P``%!```"`!``#$#P``H@\``&X/```#>#NQ
M0APO*PB_$$82^`$[`"OXT7!'`+\XM?BQ!7@$1N6Q_O?^ZP$X(AB40@S2(UPO
M*S714QX"X!%X+RDPT:-"&D8#\?\S]]&40@W1+RTTT!U(O>@X0'A$_O=@NQM(
MO>@X0'A$_O=:NP$Z`^`1>"\I!-$:1I1"`O'_,_?3$AN3'+/U@%^(OP`@"=@1
M2"%&`3)/](!3>$0$1O[W.NL@1CB]4QX"X!%X+RG>T)Q"&D8#\?\S]].40LG0
MUN<&2+WH.$!X1/[W*[L`O^8.``!.#@``>%,!`/`-```MZ?!!C+!&3`*M1D]\
M1$9.##1_1-_X%($/S/A$OUD!K@_%#\S7^`#`#\4D:$!(S?@LP'A$+(#_]R/\
M/DAX1/_W'_P]2'A$__<;_#Q(>$3_]Q?\.TAX1/_W$_PZ2'A$__</_#E(>$3_
M]PO\.$AX1/_W!_Q`1O_W!/PU2'A$__<`_#1(>$3_]_S[,T@Q1GA$__>O^QBQ
M`49`1O_W)OPO2#%&>$3_]Z7[(+$!1BU(>$3_]QO\+$@Q1GA$__>:^XBQ`48I
M2'A$__<0_"A)*4AY1'A$__<*_`N:.VB:0A[1#+"]Z/"!)$@Q1GA$__>"^WBY
M(DD*(@WQ&0!Y1/[WLNL`*./1'D@-\2,!>$3_]^[[W.<!1AM(>$3_]^C[UN?^
M]YSJ`+^<#0``>E$!`!@!``">#@``-@X``#@.```X#@``/`X``#P.``!$#@``
MV`T``$`.``!*#@``Q@T``$0.``!$#@``3`X``$X.``!Z#0``K`\``,(-```N
M#@``,@X``*8-``":#0``$DD32GE$$TL0M7M$C%B"L!AH(V@!DT,<!=`!FB-H
MFD(2T0*P$+T,2&E&>$3_]Q[[,+$`>#`H&+\`*!2_`2``(`9+>T088.CG_O="
MZ@10`0`8`0``5E$!`/X,```>40$`"+7^]_CI_O?JZ0"Q`&@(O2!+(4I[1"WI
M\$&&L)Q8!48>3@2I(VA^1#!&!9/_]^[Z*480LP-X!T;[L?[WOND`NRA&_O>0
MZH!&.$;^]XSJ0$0",/[W9.H22T_P_S("EWM$S>D`4P]+`2%[1(!&_O>8ZD%&
M,$;_]T;[`^`+2'A$__=!^P6:(VB:0@+1!K"]Z/"!_O?NZ91/`0`8`0``*@T`
M`!8,```0#```U`P``"WI\$^M]0%-W_@<5Y&PW_@<IPWUH'M]1-_X%#<J'0:0
M^D0%\1`,!\JK\?@(6O@#,*OQX`0H-:OQ[`FK\?P''D8+DXCH!P"\Z`\`UO@`
MX"9&#\8-]0%#G.@#`#PSP_@`X,;I``&5Z`<`B>@'`#E&W_C$!GA$__=T^B"Q
M`W@%1@`K0/!;@?_W9O\&1@`H`/!<@3!&_O<2ZD```3#^]^KI,W@*D(.QW_B0
ME@J=^40`DRA&2T9/\/\R`2$"-?[W'.H6^`$_`"ORT5OXX`P8N13@5/@$#XBQ
M.4;_]T/Z!48`*/;0`W@`*_/0__?C^P`H[]`H1O[W8ND$1IBY`"58^"5``"QL
MT"-X`"MIT"!&`37_]]#[`"CRT"!&_O=0Z0`H[=`$1B!&W_@89O[WR.G=^"B0
M?D0%1DA&_O?`Z05$!?($12A&_O>6Z=_X^#5/\/\R`2%[1,WI`3;?^.PUS?@,
MD'M$`)2`1O[WR.E`1D_TX''^]];I`3`%T?[WN.D":!$J0/!Z@M_XQ#5:^`-@
M,&C^]T#J048`]:1R`R#^]R[J!$8`L]_XK"4!(0:;`"9:^`(`W_B@)1MH>D3-
M^`"``&C^]\[I#?4!0S!&/#,::`N;&VB:0D#PE8(-]0%-$;"]Z/"/`"2?YS!H
M_O<4ZM#X6#$#]'!#L_6`3]31,&C^]PKJT/A@D?[WI.B!1<O1,&C^]P#JT/A8
M,</S"`.S]>!_P=$H1O[W*.DY1@9&W_@L!7A$__>9^0`H`/"I@`:;'6C^][[H
M`48H1O_W4/P%1@`H`/"=@"A&_O<TZ0,H!T80V=_X_!0$."A$>43^]UKH0+D$
M+P#PWH$O1!?X!3PO*P#PV('_]SO^,+D!1BA&_O?NZ`J0`"A^T=_XS!3?^,P$
M>43?^,AT>$3?^,BD__?9^7]$_O?ZZ-_XO#3?^+P43_#_,GM$`9/?^+0T>43-
M^`"`^D0#D7M$`2'?^*B4^40"D#!&_O<,Z3M&1T:81A3@_O<`Z0-H$2L7T?[W
MV.@!-,WX$)`J1@.44T;-^`2``2$`EP*0,$;^]_3H3_3@<3!&_O<"Z4,<!4;B
MT+A&0$;^]Q[HW_A4!#%&>$3_]Y/Y,$;_]Q;^0>?_]Q/^*$;^]SKH!D8ZYP5&
M">N%!@0^5O@$#W"Q.48!-?_W`?D`*/;0`W@`*_/0_O<FZ``H[-`&1HWF#2#?
M^`AD_O=ZZ%,C?D0*D([F!IL=:%_GJ_$$"4_P_S-O\!$"`B0`E/[W4.A)1@8B
M"IC]]\KO&_@$/".YF?@!,$,K`/!L@0`D`"(`(P"4"IBK\<@'_O<ZZ,RAT>D`
M`<VCT^D`([QGQ^D"`:OQD`$,D<JAT>D``<?I!"/*H]/I`"/'Z08!R:'1Z0`!
MQ^D((P`B`",-E,?I"B/'Z0PC2^DR`<WI#FA/]`!"248*F/WWC.\$'G'=U^D*
M`>8`(D;C%\WI!B,S&`B3#9L]:WYK"9/=Z0@CBT((OX)"`M(!-4;Q``8&F[AO
M6@\'FT+JPP);#U49W>D($D/K!@8]8WYCQ^D*$@`H1]#`\4`&#)NF0DE&&$2H
MOR9&,D;]]W;ONV\S1+MG0"N_T3A&I!M.1/[W'_H_+"C=I/%`"@;Q@`@J\#\#
M!O%`#IA$KO%`!*OQD`P@:!`T5/@,'&5&5/@(+`SQ$`Q4^`0\=$4/Q?'1.$;^
M]__Y!/%`#L9%YM%/ZIH48QRJZX04!NN#%C%&2",B1@R8_?>,[[QGA^=.1LKG
M"IBK\9`)W>D.:/[W:.B\:H`A/6O$\\4"4QPX*PGX`A``\Y*`">L#`,/Q.`(`
M(?WW]N\X1B(.A_AS4"L.A_AT(*OQ,`F'^'=`A_AP,"L,+0J'^'$PA_AR4",,
M)`J'^'4PA_AV0/[WMOE;^,C,J_%$`KUHJ_$("SQIN&E/ZAQ!47!/ZAQC.6HO
M#A=Q+PQ7<7I/"_@\/-5Q?T0M"M1RE7$E#M!S%7(E#-%T)`I5<A5&E'($#A1S
M!`P`"E1SD'-,1@@.$'0(#`D*4'21=(+X`\!/ZAPL@O@"P`'@%?@!/P"3($8[
M1D_P_S(!(0(T_?=^[Z-%\M%B2$_P_S)A2P$A>$3-^`B0`Y![1,WX`(`P1@&3
M`".)^"@P6TM[1/WW9N]ZY@:;7V@`+S_T(ZXX1OWW0.\#*'_V':Y4200X.$1Y
M1/WW9NX`*`B_/482YL/Q0`()ZP,``"']]V3O.$;^]SSY2$8X(@`A_?=<[V3G
M-4@!(0:;`"9:^```&VC-Z0""1$H`:'I$_?=D[Y7EF?@",$$K?_2/KIGX`S!#
M*W_TBJZ9^`0P2"M_](6NF?@%,$4K?_2`K@"43_#_,PJ<;_`Y`B!&_?>Z[DE&
M($8I(OWW-.XQ2S%,3_#_,GM$`9,P2WQ$S?@(D`$AS?@`@#!&`Y1[1/WW_NX1
MYOWW8NZ)J\WO`````/[<NI@`````=E0R$`````#PX=+#``````$C16<`````
M/E`!`-Q.`0`8`0``.@L``!(,``"B"P``A@H``&@+```@`0``*`$``&H+``#L
M"@``$`L``%(+``"`"0``+@D``-H*```<"0``D`L``,8*``!^"P``@`@``#0)
M```:!P``2`@``,0%``!>!P``,@<``$X&``#V!```;`<``(P&``"72IA)+>GP
M3WI$A["62P2N`I906`%H`Y`%D=18(&C]]R+O!48@:/WW'N^5^&@P,4:`^&DP
MC4AX1/[WOOX8L0-X,2L`\.F`__>_^B!H_?<*[X=)"R,!(GE$_?="[@`H8]"$
M2@%I>D34^`"@4FC1^!B``2I;W=_X`+)/](!I?TO`\B`)^T0`)GM$`24`DRC@
M`FC;^`@`U/@`H)-H4/@E<`GJ`P.S]8!O"+\1:0S04$8!D?WWV.X!F0(C`"()
M:/WWX.W4^`"@`48X1OWW4NT`FUMH`"A`\)2``34!-JM"0/./@%!&_??`[D%&
M`",R1OWW?NX!1@`HR]%B2M3X`*!Z1%)H41ZQ0A+1`2H0W5Y.`2501GY$`.`@
M:/WWINY!1OWW4NUS:`$UJT+UW-3X`*!01OWWFNY520,C`2)Y1/WWTNT%1FBQ
M(&C]]X[N*VE02AEH>D3]]X3M*VD;:)MH6P)LU"!H_?>`[DI)`R,!(GE$_?>X
M[05&>+%'2`*9>$3^]QW^!D8@:``N3=#]]V[N*VDR1AEH_?=D[2!H_?=F[C]-
M?40&1B!H_?=@[CU)`2)Y1/WWPNT[2GI$`48P1OWW4.T@:/WW4NX`(@*9`T8V
M2(/X:2!X1/[W\OT$1NA@F+%/].!Q($;]]\CM0QP1*!B_`2LNV`.;!9H;:)I"
M)]$'L+WH\(\:1G[GJ&C_]RC[!$;H8``HY-$E2'A$_?>@[4-X`"L_]!6O$>?]
M]R#N(4LJ:7M$FV@0:!EH_O>;_ZWG(&C]]Q3N*VD9:/WWJNV*Y_WWZ.P820-&
M&$@B1GE$>$2):`EH_?=\[4Q'`0`8`0``(`$``"($``"V!0``A$@!`&9(`0!B
M2`$`[$<!`-A'`0#<!```R@0``+8$``"8`@``3$<!`'H$``"*!```-@(``#($
M``"^1@$`E$8!`!($```XM05&__<D^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_
M]SGZ`"T8OP`H`-$XO2MX`"O[T`9)($8$(GE$_?>:[0`H\]$H1KWH.$#^]Y"^
M.`(```5+$+1[1`5,&UD#L1MH7?@$2_WWA;P`OTA$`0`P`0``+>GX0P=&"TZ(
M1@M-D49^1/WW!.Q]1'8;MA`)T``D`315^`0[2D9!1CA&F$>F0O;1O>CX@PI#
M`0``0P$`<$<`OPA`+>D(@+WH`0`"`'!E<FQX<VDN8P```%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@`````"X````N+@``)7,O)7,````O<')O
M8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90!005)?5$5-4```
M``!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"````
M`%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%
M````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!
M4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M`%!!4E]#3$5!3CT``$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````
M)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!0051(`````"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``'!A<FP`````
M+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T
M96UP+25U+25U)7,`````05)'5@`````8````<&5R;``````P````4$%2.CI0
M86-K97(Z.E9%4E-)3TX`````,2XP-#$```!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M
M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD
M;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@
M+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA
M;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T
M.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE
M<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN
M4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D
M<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]
M"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@
M7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@
M)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL
M;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-
M4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X
M="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI
M<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@
M;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D
M*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE
M;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G
M/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN
M;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO
M8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI
M('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N
M*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA
M<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A
M;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B
M(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)
M3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*
M)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N
M=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I
M*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D
M9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2
M+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L
M(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I
M;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D
M:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*
M<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@`0G?]_`0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(D8``!)&````0````$````!````RP$`
M``$````:`@```0```',#```,````G!(```T```#`.@``&0```)A]`0`;````
M!````!H```"<?0$`'`````0```#U_O]OM`$```4```"`"0``!@```*`"```*
M````[P0```L````0````%0`````````#````L'X!``(``````@``%````!$`
M```7````G!```!$```"L#P``$@```/`````3````"````!X````(````^___
M;P$```C^__]O3`\``/___V\#````\/__;W`.``#Z__]O$0``````````````
M``````````````````````````````````````````"@?0$```````````"H
M$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2
M``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(`
M`*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``
MJ!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H
M$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``J!(``*@2
M``"H$@``J!(``*@2``"H$@``J!(``*@2``"H$@``O3H`````````````````
M````````````````````````````!(`!``````"!.@```````,D5````````
M````````````````!(`!`/____\P/@``_#H````````</```(#P``"0^``!D
M.P``+#X````````0/@``&#X````````X/@``1T-#.B`H56)U;G1U+TQI;F%R
M;R`W+C(N,"TQ.75B=6YT=3$I(#<N,BXP`$=#0SH@*%5B=6YT=2],:6YA<F\@
M-BXT+C`M.'5B=6YT=3$I(#8N-"XP(#(P,3<Q,#$P`$$R````865A8FD``2@`
M```%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T
M86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-
M+F%T=')I8G5T97,`````````````````````````````````````````````
M````````````"P````$````"````5`$``%0!```9```````````````!````
M`````!,````'`````@```'`!``!P`0``(```````````````!``````````A
M````!P````(```"0`0``D`$``"0```````````````0`````````-````/;_
M_V\"````M`$``+0!``#L````!0`````````$````!````#X````+`````@``
M`*`"``"@`@``X`8```8````#````!````!````!&`````P````(```"`"0``
M@`D``.\$``````````````$`````````3@```/___V\"````<`X``'`.``#<
M````!0`````````"`````@```%L```#^__]O`@```$P/``!,#P``8`````8`
M```#````!`````````!J````"0````(```"L#P``K`\``/`````%````````
M``0````(````<P````D```!"````G!```)P0`````@``!0```!4````$````
M"````'P````!````!@```)P2``"<$@``#```````````````!`````````!W
M`````0````8```"H$@``J!(``"`#``````````````0````$````@@````$`
M```&````R!4``,@5``#X)``````````````(`````````(@````!````!@``
M`,`Z``#`.@``"```````````````!`````````".`````0````(```#(.@``
MR#H``*0_``````````````0`````````E@````$``'""````;'H``&QZ```(
M````#0`````````$`````````*$````!`````@```'1Z``!T>@``!```````
M````````!`````````"K````#@````,```"8?0$`F'T```0`````````````
M``0````$````MP````\````#````G'T!`)Q]```$```````````````$````
M!````,,````&`````P```*!]`0"@?0``$`$```8`````````!`````@```#,
M`````0````,```"P?@$`L'X``%`!``````````````0````$````T0````$`
M```#`````(`!``"```!````````````````$`````````-<````(`````P``
M`$"``0!`@```&!``````````````!`````````#<`````0```#``````````
M0(```%X```````````````$````!````Y0````,``'```````````)Z````S
M```````````````!``````````$````#``````````````#1@```]0``````
.`````````0``````````
